latin_palette: Latin Palette Generator.

View source: R/latinpalettes.R

latin_paletteR Documentation

Latin Palette Generator.

Description

This function builds palettes based on album covers by a selection of latin artists. The selection has been subjectively made by the author, my apologies. Almost all palettes, except for ozuna and rosalia, have been checked for color blind safety using Chroma.js Color Palette Helper.

Usage

latin_palette(name, n, type = c("discrete", "continuous"))

Arguments

name

Name of the color palette. Current options are aventura, badbunny1, badbunny2, badgyal, beckyg, calle13, daddy1, daddy2, don, ivyqueen, karolg, natti, nicky, ozuna, planb, rosalia, shakira, wyy.

n

Number of colors to be used. Each palette includes up to 9 colors for discrete palettes. Any n can be chosen for continuous palettes.

type

Usage of palette as "continuous" or "discrete". Continuous palettes interpolate the three first colors of the palette to create a gradient. If not specified, function assumes continuous if n>9 and discrete if n<9.

Value

A vector of n colors

Examples

latin_palette("rosalia",n=50,type="continuous")

latin_palette("daddy1",5)

latin_palette("badgyal",100)


jbgb13/peRReo documentation built on Sept. 26, 2022, 11:16 p.m.