View source: R/latinpalettes.R
| latin_palette | R Documentation |
This function builds palettes based on album covers by a selection of latin artists. The selection has been subjectively made by the author, my apologies. Almost all palettes, except for ozuna and rosalia, have been checked for color blind safety using Chroma.js Color Palette Helper.
latin_palette(name, n, type = c("discrete", "continuous"))
name |
Name of the color palette. Current options are |
n |
Number of colors to be used. Each palette includes up to 9 colors for discrete palettes. Any |
type |
Usage of palette as "continuous" or "discrete". Continuous palettes interpolate the three first colors of the palette to create a gradient. If not specified, function assumes continuous if n>9 and discrete if n<9. |
A vector of n colors
latin_palette("rosalia",n=50,type="continuous")
latin_palette("daddy1",5)
latin_palette("badgyal",100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.